# OctoBot-Backtesting [1.5.1](https://github.com/Drakkar-Software/OctoBot-Backtesting/blob/master/CHANGELOG.md)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/aa0b156e99604b3c98923fffeaea6a49)](https://app.codacy.com/gh/Drakkar-Software/OctoBot-Backtesting?utm_source=github.com&utm_medium=referral&utm_content=Drakkar-Software/OctoBot-Backtesting&utm_campaign=Badge_Grade_Dashboard)
[![PyPI](https://img.shields.io/pypi/v/OctoBot-Backtesting.svg)](https://pypi.python.org/pypi/OctoBot-Backtesting/)
[![Build Status](https://api.travis-ci.com/Drakkar-Software/OctoBot-Backtesting.svg?branch=master)](https://travis-ci.com/Drakkar-Software/OctoBot-Backtesting) 
[![Build status](https://ci.appveyor.com/api/projects/status/sisct9xel9yggme8?svg=true)](https://ci.appveyor.com/project/Herklos/octobot-backtesting)

OctoBot backtesting engine package.